COMPMID-1188: Add quantization info support in graph FC layer.

Change-Id: Ie9a6a896da142198243139fb9f8be0f83b87ccce
Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/142130
Tested-by: Jenkins <bsgcomp@arm.com>
Reviewed-by: Vidhya Sudhan Loganathan <vidhyasudhan.loganathan@arm.com>
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
diff --git a/arm_compute/graph/GraphBuilder.h b/arm_compute/graph/GraphBuilder.h
index 191848c..5bb1df4 100644
--- a/arm_compute/graph/GraphBuilder.h
+++ b/arm_compute/graph/GraphBuilder.h
@@ -212,17 +212,21 @@
     static NodeID add_flatten_node(Graph &g, NodeParams params, NodeIdxPair input);
     /** Adds a fully connected layer node to the graph
      *
      * @param[in] g                Graph to add the layer to
      * @param[in] params           Common node parameters
      * @param[in] input            Input to the fully connected layer node as a NodeID-Index pair
      * @param[in] num_outputs      Number of output neurons
      * @param[in] weights_accessor (Optional) Accessor of the weights node data
      * @param[in] bias_accessor    (Optional) Accessor of the bias node data
      *
      * @return Node ID of the created node, EmptyNodeID in case of error
      */
     static NodeID add_fully_connected_layer(Graph &g, NodeParams params, NodeIdxPair input, unsigned int num_outputs,
-                                            ITensorAccessorUPtr weights_accessor = nullptr, ITensorAccessorUPtr bias_accessor = nullptr);
+                                            ITensorAccessorUPtr weights_accessor = nullptr, ITensorAccessorUPtr bias_accessor = nullptr,
+                                            const QuantizationInfo weights_quant_info = QuantizationInfo(),
+                                            const QuantizationInfo out_quant_info     = QuantizationInfo());
     /** Adds a normalization layer node to the graph
      *
      * @param[in] g         Graph to add the node to
@@ -212,17 +212,21 @@
     /** Adds a fully connected layer node to the graph
      *
-     * @param[in] g                Graph to add the layer to
-     * @param[in] params           Common node parameters
-     * @param[in] input            Input to the fully connected layer node as a NodeID-Index pair
-     * @param[in] num_outputs      Number of output neurons
-     * @param[in] weights_accessor (Optional) Accessor of the weights node data
-     * @param[in] bias_accessor    (Optional) Accessor of the bias node data
+     * @param[in] g                  Graph to add the layer to
+     * @param[in] params             Common node parameters
+     * @param[in] input              Input to the fully connected layer node as a NodeID-Index pair
+     * @param[in] num_outputs        Number of output neurons
+     * @param[in] weights_accessor   (Optional) Accessor of the weights node data
+     * @param[in] bias_accessor      (Optional) Accessor of the bias node data
+     * @param[in] weights_quant_info (Optional) Weights quantization info
+     * @param[in] out_quant_info     (Optional) Output quantization info
      *
      * @return Node ID of the created node, EmptyNodeID in case of error